var config = require('../../config');
let app = getApp();
Page({
  data: {
    stepAuth: false,
    getStepLoading: false,
    // commitStepPopupShow: false, // 同步步数成功弹窗
    activityExplainShow: false, // 活动说明弹窗
    currentSteps: 0,
    targetSteps: 0,
    stepRecordList: [],
  },
  
  onLoad() {
    wx.getSetting({
      success:(res) => {
        // 微信步数是否授权
        if (res.authSetting['scope.werun']) {
          this.setData({
            stepAuth: true
          });
          this.getWeRunData();
        }
      }
    });
  },

  // 找微信获取步数加密数据
  getStep() {
    if (wx.getStorageSync('getStepLoading') && Date.now() - wx.getStorageSync('getStepLoading') < 60000) {
      wx.showToast({
        title: '已是最新步数，建议前往微信运动获取最新步数再返回同步',
        icon: 'none',
        duration: 2000
      });
      return;
    }
    if (this.data.getStepLoading) return;
    this.data.getStepLoading = true;
    // 查看微信运动步数授权信息
    if (this.data.stepAuth) {
      this.getWeRunData();
    } else {
      // 调起授权窗口
      wx.authorize({
        scope: 'scope.werun',
        // 授权成功
        success:() => {
          this.setData({
            stepAuth: true
          });
          this.getWeRunData();
        },
        // 授权失败，因为用户拒绝或者用户曾经拒绝过，而且在这里不能直接去到openSetting页，需要通过一个弹窗中转过去
        fail:(err) => {
          console.log('getStep err',err)
          this.authorizationFail();
        }
      });
    }
  },

  // 拿到微信运动步数加密数据
  getWeRunData() {
    wx.getWeRunData({
      success:(res) => {
        console.log('getWeRunData', res)
        // this.changeShowPopup();
        this.getStepNum(res.encryptedData, res.iv);
      },
      complete:() => {
        setTimeout(() => {
          this.data.getStepLoading = false;
        }, 100);
      }
    });
  },

  // 找后端获取解密步数信息
  getStepNum(encryptedData, iv) {
    wx.request({
      url: config.service.hostUrl + "/v1/get_step_num",
      data: {
        encrypted_data: encryptedData,
        iv: iv
      },
      header: {
        'Authorization': app.globalData.token
      },
      method: 'POST',
      success:(res) => {
        const resData = res.data.data;
        // 数据处理，结合两个数组判断是否显示打卡角标和状态
        const joinDate = [];
        resData.records_info.forEach(item => {
          joinDate.push(item.period);
        });
        resData.step_data.forEach(item => {
          if (joinDate.indexOf(item.period) > -1) {
            if (resData.records_info[joinDate.indexOf(item.period)].daka_done) {
              item.status = 1; // 打卡成功
            } else {
              item.status = 2; // 打卡失败
            }
          } else {
            item.status = 0; // 未参与打卡
          }
        });
        console.log(resData.step_data)
        this.setData({
          currentSteps: (resData.step_data && resData.step_data[0]) ? resData.step_data[0].step : 0,
          targetSteps: resData.total_step,
          stepRecordList: resData.step_data
        });
        wx.setStorageSync('getStepLoading', Date.now());
        wx.showModal({
          content: '获取微信运动步数成功',
          showCancel: false
        });
      },
      fail:(err) => {
        console.log('fail', err);
      }
    });
  },

  // 授权失败，去到openSetting页
  authorizationFail() {
    wx.showModal({
      content: '如需完成步数打卡，请点击确定允许微信授权',
      success:(res) => {
        if (res.confirm) {
          wx.openSetting({
            success:(res) => {
              if (res.authSetting['scope.werun']) {
                this.setData({
                  stepAuth: true
                });
                this.getWeRunData();
              } else {
                // this.authorizationFail();
              }
            }
          });
        }
      },
      complete:() => {
        setTimeout(() => {
          this.data.getStepLoading = false;
        }, 100);
      }
    });
  },
  
  // 活动说明弹窗
  changeActivityExplainShow() {
    this.setData({
      activityExplainShow: !this.data.activityExplainShow
    });
  },

  // // 同步步数成功弹窗
  // changeShowPopup() {
  //   this.setData({
  //     commitStepPopupShow: !this.data.commitStepPopupShow
  //   });
  // },

  // goAuthorizationPage() {
  //   console.log(`/pages/authorization/authorization?userAuth=${this.data.userAuth}&stepAuth=${this.data.stepAuth}`)
  //   wx.navigateTo({
  //     url: `/pages/authorization/authorization?userAuth=${this.data.userAuth}&stepAuth=${this.data.stepAuth}`
  //   });
  // },

  // goCaptionPage() {
  //   wx.navigateTo({
  //     url: '/pages/caption/caption'
  //   });
  // },
})